=======================================
Welcome to kafka-tools's documentation!
=======================================

Kafka tools.

.. toctree::
   :maxdepth: 2

   getting_started
   commands
   contributing

API Documentation
=================

.. toctree::
   :maxdepth: 2

   tools/assigner/tools

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
